macholib.MachOStandalone — Create standalone application bundles — macholib v1.4.1 documentation

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.1 documentation »

# `macholib.MachOStandalone` — Create standalone application bundles

This module defines class `MachOStandalone` which locates all Mach-O files in a directory (assumed to be the root of an application or plugin bundle) and then copies all non-system dependencies for the located files into the bundle.

class `macholib.MachOStandalone.` `MachOStandalone`(base[, dest[, graph[, env[, executable_path]]]])

### Navigation

- index
- modules |
- next |
- previous |
- macholib v1.4.1 documentation »